@@ -1,6 +1,9 @@
 import base64
 import hmac
 import time
+
+from ks3 import utils
+
 try:
     import urllib.parse as parse  # for Python 3
 except ImportError:
@@ -32,9 +35,9 @@ qsa_of_interest = ['acl', 'cors', 'defaultObjectAcl', 'location', 'logging',
 def url_encode(key):
     if not key:
         return ""
-    encode_key = parse.quote_plus(key.encode('utf-8'))
-    if '%20' in encode_key:
-        encode_key = encode_key.replace('%20', '+')
+    encode_key = parse.quote(utils.get_utf8_value(key))
+    # if '%20' in encode_key:
+    #     encode_key = encode_key.replace('%20', '+')
 
     if '%2A' in encode_key:
         encode_key = encode_key.replace('%2A', '*')
