@@ -237,6 +237,32 @@ class Bucket(object):
         key, resp = self._get_key_internal(key_name, headers, query_args_l)
         return key
 
+    def get_key_meta(self, key_name, headers=None, version_id=None,
+                response_headers=None, validate=True):
+        """
+        Check to see if a particular key exists within the bucket.
+        """
+        if validate is False:
+            # if headers or version_id or response_headers:
+            #     raise BotoClientError(
+            #         "When providing 'validate=False', no other params " + \
+            #         "are allowed."
+            #     )
+
+            # This leans on the default behavior of ``new_key`` (not hitting
+            # the service). If that changes, that behavior should migrate here.
+            return self.new_key(key_name)
+
+        query_args_l = {}
+        if version_id:
+            query_args_l['versionId'] = version_id
+        if response_headers:
+            for rk, rv in six.iteritems(response_headers):
+                query_args_l[rk] = parse.quote(rv)
+
+        k, resp = self._get_key_internal(key_name, headers, query_args_l)
+        return resp
+
     def _get_key_internal(self, key_name, headers, query_args_l):
         query_args = query_args_l or None
         response = self.connection.make_request('HEAD', self.name, key_name,
@@ -313,7 +339,7 @@ class Bucket(object):
                         if fd:
                             fd.write("{}\n".format(k.name))
                 elif endTime is not None and startTime is not None:
-                    if (startTime <= datetime & datetime <= endTime):
+                    if startTime <= datetime or datetime <= endTime:
                         keyLists.append(k.name)
                         if fd:
                             fd.write("{}\n".format(k.name))
@@ -334,6 +360,16 @@ class Bucket(object):
                                             headers,
                                             encoding_type=encoding_type)
 
+    def list_v2(self, **params):
+        """
+        List object V2.
+        """
+        params_v2 = params.copy()
+        params_v2['list_type'] = 2
+        if not params_v2['delimiter']:
+            params_v2['delimiter'] = '/'
+        return BucketListResultSet(self, **params_v2)
+
     def get_all_keys(self, **params):
         """
         A lower-level method for listing contents of a bucket.
@@ -394,11 +430,16 @@ class Bucket(object):
         return '&'.join(pairs)
 
     def set_xml_acl(self, acl_str, key_name='', headers=None, version_id=None,
-                    query_args={'acl': ''}):
+                    query_args=None):
+        if query_args is None:
+            query_args = {'acl': ''}
         if version_id:
             query_args['versionId'] = version_id
         if not isinstance(acl_str, bytes):
             acl_str = acl_str.encode('utf-8')
+        if headers is None:
+            headers = {}
+        headers['content-type'] = 'application/xml'
         response = self.connection.make_request('PUT', self.name, key_name,
                                                 data=acl_str,
                                                 query_args=query_args,
@@ -495,9 +536,10 @@ class Bucket(object):
         body = logging_xml
         if not isinstance(body, bytes):
             body = body.encode('utf-8')
-            # md5 = ks3.utils.compute_base64_md5_digest(body)
-            # headers['Content-MD5'] = md5
-            headers['content-type'] = 'application/xml'
+
+        # md5 = ks3.utils.compute_base64_md5_digest(body)
+        # headers['Content-MD5'] = md5
+        headers['content-type'] = 'application/xml'
         response = self.connection.make_request('PUT', self.name, data=body,
                                                 query_args='logging', headers=headers)
         body = response.read()
