@@ -236,7 +236,7 @@ class Connection(object):
         if location == None:
             data = ''
         else:
-            data = '<CreateBucketConfiguration><LocationConstraint>' + \
+            data = '<CreateBucketConfiguration xmlns="http://s3.amazonaws.com/doc/2006-03-01/"><LocationConstraint>' + \
                    location + '</LocationConstraint></CreateBucketConfiguration>'
 
         query_args = {}
