@@ -63,7 +63,7 @@ def get_object_url(age, bucket="", key="", secret_access_key="", access_key_id="
 
 def make_request(server, port, access_key_id, access_key_secret, method, 
                  bucket="", key="", query_args=None, headers=None, data="", 
-                 metadata=None, call_fmt=CallingFormat.PATH, is_secure=False,domain_mode=False,need_auth_header=True, timeout = 10, ua_addon=''):
+                 metadata=None, call_fmt=CallingFormat.SUBDOMAIN, is_secure=False,domain_mode=False,need_auth_header=True, timeout = 10, ua_addon=''):
     if not headers:
         headers = {}
     #if not query_args:
@@ -114,7 +114,11 @@ def make_request(server, port, access_key_id, access_key_secret, method,
         if loc:
             reg = re.findall('http[s]?://(.*?)(:\d+)?/', loc)
             if reg:
-                new_server = reg[0][0]
+                # 如果返回的是bucket style域名，需要提取region域名出来
+                if len(reg[0][0].split('.')) == 4:
+                    new_server = reg[0][0].split('.', 1)[1]
+                else:
+                    new_server = reg[0][0]
                 loc_parse = urlparse.urlparse(loc)
                 if 'Signature' in loc_parse.query:
                     connection_temp = httpcli.HTTPSConnection(new_server)
@@ -145,8 +149,6 @@ def make_request_v4(access_key_id, access_key_secret, method='', service='', reg
     if query_args:
         if isinstance(query_args, dict):
             query_args = query_args_hash_to_string(query_args)
-        else:
-            query_args = query_args
     path += "?" + query_args
 
     headers = add_auth_header_v4(access_key_id, access_key_secret, region, service, host, method, query_args, body,
