@@ -155,16 +155,18 @@ class MultiPartUpload(object):
         self.crypt_context = crypt
 
     def startElement(self, name, attrs, connection):
-        #if name == 'Initiator':
-        if name == 'ns2:Initiator':
+        if name.startswith("ns2"):
+            name = name.split(":")[1]
+        if name == 'Initiator':
+        # if name == 'ns2:Initiator':
             self.initiator = user.User(self)
             return self.initiator
-        #elif name == 'Owner':
-        elif name == 'ns2:Owner':
+        elif name == 'Owner':
+        # elif name == 'ns2:Owner':
             self.owner = user.User(self)
             return self.owner
-        #elif name == 'Part':
-        elif name == 'ns2:Part':
+        elif name == 'Part':
+        # elif name == 'ns2:Part':
             part = Part(self.bucket)
             self._parts.append(part)
             return part
@@ -280,11 +282,11 @@ class MultiPartUpload(object):
             # key.set_contents_from_file() raise an exception when fail.
             self.size_accumulator[part_num] = part_size
         else:
-            key.set_contents_from_file(fp, headers=headers, replace=replace,
+            response = key.set_contents_from_file(fp, headers=headers, replace=replace,
                                        cb=cb, num_cb=num_cb, md5=md5,
                                        reduced_redundancy=False,
                                        query_args=query_args, size=size)
-        return key
+        return response
     def add_all_part(self, part_num):
         sum = 0
         for i in range(1,part_num):
